@@ -11,7 +11,7 @@ from muffin.plugins import BasePlugin
 from peewee_migrate import Router
 
 
-__version__ = "1.7.15"
+__version__ = "1.8.0"
 __project__ = "muffin-peewee"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -118,7 +118,7 @@ class Plugin(BasePlugin):
 
     async def __aenter__(self):
         """Connect async and enter the database context."""
-        await self.database.obj.__aenter__()
+        return await self.database.obj.__aenter__()
 
     async def __aexit__(self, *args):
         """Exit from the database context."""
